==> qtjambi-qml-debuginfo-macos-6.8.1.jar: sources/QtJambiQml/QtQml_QQmlAttachedPropertiesFunc_shell.cpp <==
#include "QtQml_QQmlAttachedPropertiesFunc_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QtQml_QQmlAttachedPropertiesFunc(void *ptr,bool) { delete reinterpret_cast<QtQml_QQmlAttachedPropertiesFunc_shell*>(ptr); }


QtQml_QQmlAttachedPropertiesFunc_shell::QtQml_QQmlAttachedPropertiesFunc_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QtQml_QQmlAttachedPropertiesFunc_shell::QtQml_QQmlAttachedPropertiesFunc_shell()", this)
    QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->constructed(typeid(QtQml::QQmlAttachedPropertiesFunc));
}

// emitting (writeShellDestructor)
QtQml_QQmlAttachedPropertiesFunc_shell::~QtQml_QQmlAttachedPropertiesFunc_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtQml_QQmlAttachedPropertiesFunc_shell::~QtQml_QQmlAttachedPropertiesFunc_shell()", this)
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->destructed(typeid(QtQml::QQmlAttachedPropertiesFunc));
}

// construct QtQml_QQmlAttachedPropertiesFunc_shell
void __qt_construct_QtQml_QQmlAttachedPropertiesFunc(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool, bool, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QtQml::QQmlAttachedPropertiesFunc")
    new (__qtjambi_ptr) QtQml_QQmlAttachedPropertiesFunc_shell();
}
// destruct QtQml_QQmlAttachedPropertiesFunc_shell
void __qt_destruct_QtQml_QQmlAttachedPropertiesFunc(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtQml::QQmlAttachedPropertiesFunc")
    reinterpret_cast<QtQml_QQmlAttachedPropertiesFunc_shell*>(ptr)->~QtQml_QQmlAttachedPropertiesFunc_shell();
}

void QtQml_QQmlAttachedPropertiesFunc_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QtQml_QQmlAttachedPropertiesFunc_shell*>(ptr)->QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->tryDeleteShell(typeid(QtQml::QQmlAttachedPropertiesFunc));
}

QtJambiShell* QtQml_QQmlAttachedPropertiesFunc_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QtQml_QQmlAttachedPropertiesFunc_shell) ); }

QtQml_QQmlAttachedPropertiesFunc_shell::Functor::Functor(QtQml_QQmlAttachedPropertiesFunc_shell& functional) : FunctorBase(typeid(QtQml::QQmlAttachedPropertiesFunc), functional) {}

QtQml_QQmlAttachedPropertiesFunc_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QtQml_QQmlAttachedPropertiesFunc_shell::Functor::~Functor() {}

QObject*  QtQml_QQmlAttachedPropertiesFunc_shell::Functor::operator()(QObject* arg__1)
{
    QObject* __qt_return_value = nullptr;
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironmentExceptionHandler env{300}) {
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_return_value = env->CallObjectMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    QObject* __qt_return_value_tmp = qtjambi_cast<QObject*>(env, __java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                env.handleException(exn, "QtQml::QQmlAttachedPropertiesFunc");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QtQml_QQmlAttachedPropertiesFunc_shell::getFunctional(JNIEnv *env, void* result)
{
    jobject __this = QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->getJavaObjectLocalRef(env);
    uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
    *reinterpret_cast<QtQml::QQmlAttachedPropertiesFunc*>(result) = qtjambi_function_pointer<14,QObject*(QObject*)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

bool QtQml_QQmlAttachedPropertiesFunc_shell::isFunctionPointer()
{
    return true;
}

jobject QtQml_QQmlAttachedPropertiesFunc_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const QtQml::QQmlAttachedPropertiesFunc& function = *reinterpret_cast<const QtQml::QQmlAttachedPropertiesFunc*>(functionPtr);
        if(const QtQml_QQmlAttachedPropertiesFunc_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QtQml_00024QQmlAttachedPropertiesFunc_00024Impl_00024ConcreteWrapper_apply_1native__J)
(JNIEnv *__jni_env, jobject __this, QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlAttachedPropertiesFunc(...)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtQml::QQmlAttachedPropertiesFunc* function = QtJambiAPI::convertJavaInterfaceToNative<QtQml::QQmlAttachedPropertiesFunc>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QObject* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QObject>(arg__1);
        QObject*  __qt_return_value = (*function)(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QtQml_00024QQmlAttachedPropertiesFunc_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtQml_QQmlAttachedPropertiesFunc_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtQml_QQmlAttachedPropertiesFunc, sizeof(QtQml_QQmlAttachedPropertiesFunc_shell), typeid(QtQml::QQmlAttachedPropertiesFunc), 0, &deleter_QtQml_QQmlAttachedPropertiesFunc);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QtQml_QQmlAttachedPropertiesFunc_shell::Functor*(QtQml::QQmlAttachedPropertiesFunc)> QtQml_QQmlAttachedPropertiesFunc_shell::reverseFunctionGetter = std::function<const QtQml_QQmlAttachedPropertiesFunc_shell::Functor*(QtQml::QQmlAttachedPropertiesFunc)>();

void initialize_meta_info_QtQml_QQmlAttachedPropertiesFunc(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QtQml::QQmlAttachedPropertiesFunc, QtQml_QQmlAttachedPropertiesFunc_shell>("QtQml::QQmlAttachedPropertiesFunc", "io/qt/qml/QtQml$QQmlAttachedPropertiesFunc",
                              false,
                              &deleter_QtQml_QQmlAttachedPropertiesFunc,
                              &__qt_destruct_QtQml_QQmlAttachedPropertiesFunc,
                              {ConstructorInfo{&__qt_construct_QtQml_QQmlAttachedPropertiesFunc, nullptr}},
                              {FunctionInfo{"apply", "(Lio/qt/core/QObject;)Lio/qt/core/QObject;", FunctionInfo::Abstract}});
}

==> qtjambi-qml-debuginfo-macos-6.9.1.jar: sources/QtJambiQml/QtQml_QQmlAttachedPropertiesFunc_shell.cpp <==
#include "QtQml_QQmlAttachedPropertiesFunc_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QtQml_QQmlAttachedPropertiesFunc(void *ptr,bool) { delete reinterpret_cast<QtQml_QQmlAttachedPropertiesFunc_shell*>(ptr); }


QtQml_QQmlAttachedPropertiesFunc_shell::QtQml_QQmlAttachedPropertiesFunc_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QtQml_QQmlAttachedPropertiesFunc_shell::QtQml_QQmlAttachedPropertiesFunc_shell()", this)
    QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->constructed(typeid(QtQml::QQmlAttachedPropertiesFunc));
}

// emitting (writeShellDestructor)
QtQml_QQmlAttachedPropertiesFunc_shell::~QtQml_QQmlAttachedPropertiesFunc_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtQml_QQmlAttachedPropertiesFunc_shell::~QtQml_QQmlAttachedPropertiesFunc_shell()", this)
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->destructed(typeid(QtQml::QQmlAttachedPropertiesFunc));
}

// construct QtQml_QQmlAttachedPropertiesFunc_shell
void __qt_construct_QtQml_QQmlAttachedPropertiesFunc(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool, bool, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QtQml::QQmlAttachedPropertiesFunc")
    new (__qtjambi_ptr) QtQml_QQmlAttachedPropertiesFunc_shell();
}
// destruct QtQml_QQmlAttachedPropertiesFunc_shell
void __qt_destruct_QtQml_QQmlAttachedPropertiesFunc(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtQml::QQmlAttachedPropertiesFunc")
    reinterpret_cast<QtQml_QQmlAttachedPropertiesFunc_shell*>(ptr)->~QtQml_QQmlAttachedPropertiesFunc_shell();
}

void QtQml_QQmlAttachedPropertiesFunc_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QtQml_QQmlAttachedPropertiesFunc_shell*>(ptr)->QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->tryDeleteShell(typeid(QtQml::QQmlAttachedPropertiesFunc));
}

QtJambiShell* QtQml_QQmlAttachedPropertiesFunc_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QtQml_QQmlAttachedPropertiesFunc_shell) ); }

QtQml_QQmlAttachedPropertiesFunc_shell::Functor::Functor(QtQml_QQmlAttachedPropertiesFunc_shell& functional) : FunctorBase(typeid(QtQml::QQmlAttachedPropertiesFunc), functional) {}

QtQml_QQmlAttachedPropertiesFunc_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QtQml_QQmlAttachedPropertiesFunc_shell::Functor::~Functor() {}

QObject*  QtQml_QQmlAttachedPropertiesFunc_shell::Functor::operator()(QObject* arg__1)
{
    QObject* __qt_return_value = nullptr;
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironmentExceptionHandler env{300}) {
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_return_value = env->CallObjectMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                    QObject* __qt_return_value_tmp = qtjambi_cast<QObject*>(env, __java_return_value);
                    __qt_return_value = __qt_return_value_tmp;
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                env.handleException(exn, this, "QtQml::QQmlAttachedPropertiesFunc");
            } QTJAMBI_TRY_END
        }
    }
    return __qt_return_value;
}

void QtQml_QQmlAttachedPropertiesFunc_shell::getFunctional(JNIEnv *env, void* result)
{
    jobject __this = QtQml_QQmlAttachedPropertiesFunc_shell::__shell()->getJavaObjectLocalRef(env);
    uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
    *reinterpret_cast<QtQml::QQmlAttachedPropertiesFunc*>(result) = qtjambi_function_pointer<14,QObject*(QObject*)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

bool QtQml_QQmlAttachedPropertiesFunc_shell::isFunctionPointer()
{
    return true;
}

jobject QtQml_QQmlAttachedPropertiesFunc_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const QtQml::QQmlAttachedPropertiesFunc& function = *reinterpret_cast<const QtQml::QQmlAttachedPropertiesFunc*>(functionPtr);
        if(const QtQml_QQmlAttachedPropertiesFunc_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_qml_QtQml_00024QQmlAttachedPropertiesFunc_00024Impl_00024ConcreteWrapper_apply_1native__J
(JNIEnv *__jni_env, jobject __this, QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlAttachedPropertiesFunc(...)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtQml::QQmlAttachedPropertiesFunc* function = QtJambiAPI::convertJavaInterfaceToNative<QtQml::QQmlAttachedPropertiesFunc>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QObject* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QObject>(arg__1);
        QObject*  __qt_return_value = (*function)(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" JNIEXPORT void JNICALL Java_io_qt_qml_QtQml_00024QQmlAttachedPropertiesFunc_00024Impl_initialize_1native
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtQml_QQmlAttachedPropertiesFunc_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtQml_QQmlAttachedPropertiesFunc, sizeof(QtQml_QQmlAttachedPropertiesFunc_shell), typeid(QtQml::QQmlAttachedPropertiesFunc), 0, &deleter_QtQml_QQmlAttachedPropertiesFunc);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QtQml_QQmlAttachedPropertiesFunc_shell::Functor*(QtQml::QQmlAttachedPropertiesFunc)> QtQml_QQmlAttachedPropertiesFunc_shell::reverseFunctionGetter = std::function<const QtQml_QQmlAttachedPropertiesFunc_shell::Functor*(QtQml::QQmlAttachedPropertiesFunc)>();

void initialize_meta_info_QtQml_QQmlAttachedPropertiesFunc(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QtQml::QQmlAttachedPropertiesFunc, QtQml_QQmlAttachedPropertiesFunc_shell>("QtQml::QQmlAttachedPropertiesFunc", "io/qt/qml/QtQml$QQmlAttachedPropertiesFunc",
                              false,
                              &deleter_QtQml_QQmlAttachedPropertiesFunc,
                              &__qt_destruct_QtQml_QQmlAttachedPropertiesFunc,
                              {ConstructorInfo{&__qt_construct_QtQml_QQmlAttachedPropertiesFunc, nullptr}},
                              {FunctionInfo{"apply", "(Lio/qt/core/QObject;)Lio/qt/core/QObject;", FunctionInfo::Abstract}});
}
